@@ -23,6 +23,69 @@ else:
     from torch.utils.checkpoint import checkpoint
 
 
+class GPT2Config:
+
+    def __init__(
+            self,
+            vocab_size=50257,
+            n_positions=1024,
+            n_ctx=1024,
+            n_embd=768,
+            n_layer=12,
+            n_head=12,
+            n_inner=None,
+            activation_function="gelu_new",
+            resid_pdrop=0.1,
+            embd_pdrop=0.1,
+            attn_pdrop=0.1,
+            layer_norm_epsilon=1e-5,
+            initializer_range=0.02,
+            summary_type="cls_index",
+            summary_use_proj=True,
+            summary_activation=None,
+            summary_proj_to_labels=True,
+            summary_first_dropout=0.1,
+            scale_attn_weights=True,
+            gradient_checkpointing=False,
+            use_cache=True,
+            bos_token_id=50256,
+            eos_token_id=50256,
+            checkpoint_activations=False,
+            hidden_size=None,
+            do_layer_norm_before=True,
+    ):
+
+        self.do_layer_norm_before = do_layer_norm_before
+        self.checkpoint_activations = checkpoint_activations
+        self.vocab_size = vocab_size
+        self.n_ctx = n_ctx
+        self.n_positions = n_positions
+        self.n_embd = n_embd
+        if hidden_size is None:
+            self.hidden_size = n_embd
+        else :
+            self.hidden_size = hidden_size
+        self.n_layer = n_layer
+        self.n_head = n_head
+        self.n_inner = n_inner
+        self.activation_function = activation_function
+        self.resid_pdrop = resid_pdrop
+        self.embd_pdrop = embd_pdrop
+        self.attn_pdrop = attn_pdrop
+        self.layer_norm_epsilon = layer_norm_epsilon
+        self.initializer_range = initializer_range
+        self.summary_type = summary_type
+        self.summary_use_proj = summary_use_proj
+        self.summary_activation = summary_activation
+        self.summary_first_dropout = summary_first_dropout
+        self.summary_proj_to_labels = summary_proj_to_labels
+        self.gradient_checkpointing = gradient_checkpointing
+        self.scale_attn_weights = scale_attn_weights
+        self.use_cache = use_cache
+
+        self.bos_token_id = bos_token_id
+        self.eos_token_id = eos_token_id
+
 class GPT2Stack(nn.Module):
 
     def __init__(self, config):
@@ -30,20 +93,20 @@ class GPT2Stack(nn.Module):
         super().__init__()
         if os.getenv("ENV_TYPE") == "deepspeed+mpu":
             self.wte = VocabParallelEmbedding(
-                config['vocab_size'],
-                config['n_embd'],
+                config.vocab_size,
+                config.n_embd,
                 init_method=normal_init_method(
-                    mean=0.0, std=config['initializer_range']))
+                    mean=0.0, std=config.initializer_range))
         else:
-            self.wte = nn.Embedding(config['vocab_size'], config['n_embd'])
-        self.wpe = nn.Embedding(config['n_positions'], config['n_embd'])
-        self.drop = nn.Dropout(config['embd_pdrop'])
+            self.wte = nn.Embedding(config.vocab_size, config.n_embd)
+        self.wpe = nn.Embedding(config.n_positions, config.n_embd)
+        self.drop = nn.Dropout(config.embd_pdrop)
         self.h = nn.ModuleList([
-            GPT2Block(config['n_ctx'], config, scale=True)
-            for _ in range(config['n_layer'])
+            GPT2Block(config.n_ctx, config, scale=True)
+            for _ in range(config.n_layer)
         ])
-        self.ln_f = nn.LayerNorm(config['n_embd'],
-                                 eps=config['layer_norm_epsilon'])
+        self.ln_f = nn.LayerNorm(config.n_embd,
+                                 eps=config.layer_norm_epsilon)
         self.device_map = None
 
     def get_input_embeddings(self):
@@ -96,7 +159,8 @@ class GPT2Stack(nn.Module):
         for i, block in enumerate(self.h):
             if output_hidden_states:
                 all_hidden_states = all_hidden_states + (hidden_states, )
-            if self.config['checkpoint_activations']:
+
+            if self.config.checkpoint_activations:
 
                 def create_custom_forward(module):
 
@@ -146,9 +210,24 @@ class GPT2Model(BaseModel):
     def __init__(self, config, **kwargs):
         super().__init__(config, **kwargs)
         self.config = config
-        self.transformer = GPT2Stack(config)
-        self.lm_head = nn.Linear(self.config['n_embd'],
-                                 self.config['vocab_size'],
+        if type(config) is dict:
+            config_gpt = GPT2Config(
+                activation_function=self.config["activation_function"],
+                n_head=self.config["n_head"],
+                n_embd=self.config["n_embd"],
+                n_layer=self.config["n_layer"],
+                n_positions=self.config["n_positions"],
+                vocab_size=self.config["vocab_size"],
+                n_inner=self.config["n_inner"],
+                checkpoint_activations=self.config["checkpoint_activations"],
+                hidden_size=self.config.get("hidden_size", None),
+                do_layer_norm_before=self.config.get("do_layer_norm_before", True),
+            )
+            self.config = config_gpt
+
+        self.transformer = GPT2Stack(self.config)
+        self.lm_head = nn.Linear(self.config.n_embd,
+                                 self.config.vocab_size,
                                  bias=False)
 
     def _make_causal_mask(self, input_ids):
@@ -212,7 +291,7 @@ class GPT2Model(BaseModel):
 
         checkpoint = self.transpose_weight(checkpoint)
 
-        self.load_state_dict(checkpoint, strict=True)
+        self.load_state_dict(checkpoint, strict=False)
         return checkpoint
 
     def transpose_weight(self, checkponts):
@@ -222,7 +301,7 @@ class GPT2Model(BaseModel):
         ]
         weight_layers_extend = []
         for layer in weight_layers_same:
-            for i in range(self.config['n_layer']):
+            for i in range(self.config.n_layer):
                 weight_layers_extend.append(f"transformer.h.{i}.{layer}")
 
         checkponts_ = {}
